@@ -10,7 +10,7 @@
 #'   a comparison operator, whitespace and a valid version number, e.g.
 #'   \code{"xgboost (>= 1.3.0)"}.
 #' @param response_types character vector of response variable types to which
-#'   the model can be fit.  Supported types are \code{"binary"}, =
+#'   the model can be fit.  Supported types are \code{"binary"},
 #'   \code{"BinomialVariate"}, \code{"DiscreteVariate"}, \code{"factor"},
 #'   \code{"matrix"}, \code{"NegBinomialVariate"}, \code{"numeric"},
 #'   \code{"ordered"}, \code{"PoissonVariate"}, and \code{"Surv"}.
@@ -20,6 +20,10 @@
 #' @param predictor_encoding character string indicating whether the model is
 #'   fit with predictor variables encoded as a \code{"\link{model.frame}"},
 #'   a \code{"\link{model.matrix}"}, or unspecified (default).
+#' @param na.rm character string or logical specifying removal of \code{"all"}
+#'   (\code{TRUE}) cases with missing values from model fitting and prediction,
+#'   \code{"none"} (\code{FALSE}), or only those whose missing values are in the
+#'   \code{"response"} variable.
 #' @param params list of user-specified model parameters to be passed to the
 #'   \code{fit} function.
 #' @param gridinfo tibble of information for construction of tuning grids
@@ -105,7 +109,8 @@
 MLModel <- function(
   name = "MLModel", label = name, packages = character(),
   response_types = character(), weights = FALSE,
-  predictor_encoding = c(NA, "model.frame", "model.matrix"), params = list(),
+  predictor_encoding = c(NA, "model.frame", "model.matrix"), na.rm = FALSE,
+  params = list(),
   gridinfo = tibble::tibble(
     param = character(), get_values = list(), default = logical()
   ),
@@ -118,6 +123,8 @@ MLModel <- function(
   stopifnot(response_types %in% settings("response_types"))
   stopifnot(length(weights) %in% c(1, length(response_types)))
 
+  na.rm <- throw(check_na.rm(na.rm))
+
   stopifnot(is_tibble(gridinfo))
   gridinfo <- new_gridinfo(
     param = gridinfo[["param"]],
@@ -132,6 +139,7 @@ MLModel <- function(
     response_types = response_types,
     weights = weights,
     predictor_encoding = match.arg(predictor_encoding),
+    na.rm = na.rm,
     params = params,
     gridinfo = gridinfo,
     fit = fit,
@@ -170,6 +178,13 @@ update.MLModel <- function(
     new_params <- as(object, "list")
     new_params[names(params)] <- params
     object <- do.call(object@name, new_params, quote = quote)
+  } else if (!.hasSlot(object, "na.rm")) {
+    info <- modelinfo(object@name)
+    object@na.rm <- if (length(info)) {
+      info[[1]]$na.rm
+    } else {
+      check_na.rm(formals(MLModel)$na.rm)
+    }
   }
   object@id <- id
   object
